@@ -4,11 +4,11 @@ mod arguments;
 mod column;
 mod connection;
 mod database;
-mod done;
 mod error;
 mod io;
 mod options;
 mod protocol;
+mod query_result;
 mod row;
 mod statement;
 mod transaction;
@@ -20,9 +20,9 @@ pub use arguments::MssqlArguments;
 pub use column::MssqlColumn;
 pub use connection::MssqlConnection;
 pub use database::Mssql;
-pub use done::MssqlDone;
 pub use error::MssqlDatabaseError;
 pub use options::MssqlConnectOptions;
+pub use query_result::MssqlQueryResult;
 pub use row::MssqlRow;
 pub use statement::MssqlStatement;
 pub use transaction::MssqlTransactionManager;
@@ -36,7 +36,6 @@ pub type MssqlPool = crate::pool::Pool<Mssql>;
 impl_into_arguments_for_arguments!(MssqlArguments);
 impl_executor_for_pool_connection!(Mssql, MssqlConnection, MssqlRow);
 impl_executor_for_transaction!(Mssql, MssqlRow);
-impl_map_row!(Mssql, MssqlRow);
 impl_acquire!(Mssql, MssqlConnection);
 impl_column_index_for_row!(MssqlRow);
 impl_column_index_for_statement!(MssqlStatement);
